Graph attribute protocol and implementations for records from loom.graph. Attributes can provide labels and styles (color, thickness, and so on).
Graph attribute protocol and implementations for records from loom.graph. Attributes can provide labels and styles (color, thickness, and so on).
(add-attr-to-all g k v)Adds an attribute to all nodes and edges
Adds an attribute to all nodes and edges
(add-attr-to-edges g k v edges)Adds an attribute to the given edges
Adds an attribute to the given edges
(add-attr-to-nodes g k v nodes)Adds an attribute to the given nodes
Adds an attribute to the given nodes
(add-attrs-to-all g & kvs)Adds attributes to all nodes and edges
Adds attributes to all nodes and edges
(attr? g)Returns true if g satisfies AttrGraph
Returns true if g satisfies AttrGraph
(add-attr g node-or-edge k v)(add-attr g n1 n2 k v)Add an attribute to node or edge
Add an attribute to node or edge
(attr g node-or-edge k)(attr g n1 n2 k)Return the attribute on a node or edge
Return the attribute on a node or edge
(attrs g node-or-edge)(attrs g n1 n2)Return all attributes on a node or edge
Return all attributes on a node or edge
(remove-attr g node-or-edge k)(remove-attr g n1 n2 k)Remove an attribute from a node or edge
Remove an attribute from a node or edge
(hilite g node)(hilite g n1 n2)Adds a red :color attribute to a node or edge
Adds a red :color attribute to a node or edge
(hilite-path g path)Highlights nodes and edges along a path.
Highlights nodes and edges along a path.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |