loom.derived

Defines derived graphs from existing graphs with maps and filters.

Defines derived graphs from existing graphs with maps and filters.
raw docstring

bipartite-subgraphclj/s

(bipartite-subgraph g subset)

Returns the subgraph of g that contains only the edge subset E that leads outside the given subset. The result contains the start and endpoints of these edges. The result is the bipartite graph (U,V,E), where U = subset, V = (map last E). (see https://en.wikipedia.org/wiki/Bipartite_graph).

Returns the subgraph of g that contains only the edge subset E that leads
outside the given subset. The result contains the start and endpoints of these
edges. The result is the bipartite graph (U,V,E), where
U = subset, V = (map last E).
(see https://en.wikipedia.org/wiki/Bipartite_graph).
sourceraw docstring

edges-filtered-byclj/s

(edges-filtered-by pred g)

Returns a new graph with all nodes of g and edges that satisfy the predicate.

Returns a new graph with all nodes of g and edges that satisfy the predicate.
sourceraw docstring

mapped-byclj/s

(mapped-by f g)

Returns a Graph or DiGraph with the nodeset (set (map f (nodes g))). An edge [uu, vv] is in the result if g has an edge [u, v] where [uu, vv] = [(f u), (f v)].

Returns a Graph or DiGraph with the nodeset (set (map f (nodes g))). An edge
[uu, vv] is in the result if g has an edge [u, v] where [uu, vv] = [(f u),
(f v)].
sourceraw docstring

nodes-filtered-byclj/s

(nodes-filtered-by pred g)

Returns a new graph with all nodes of g that satisfy the predicate.

Returns a new graph with all nodes of g that satisfy the predicate.
sourceraw docstring

subgraph-reachable-fromclj/s

(subgraph-reachable-from g start)

Returns a subgraph of the given graph. It contains all nodes and edges that are reachable from the given start node.

Returns a subgraph of the given graph. It contains all nodes and edges that
are reachable from the given start node.
sourceraw docstring

surroundingsclj/s

(surroundings g subset)

Returns the subgraph of g that contains nodes in the given subset and their direct successors.

Returns the subgraph of g that contains nodes in the given subset and their
direct successors.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries