loom.io

Output and view graphs in various formats

Output and view graphs in various formats
raw docstring

dotclj

(dot g f & args)

Writes graph g to f (a string or File) in DOT format. It passes args to dot-str.

Writes graph g to f (a string or File) in DOT format. It passes args to dot-str.
sourceraw docstring

dot-strclj

(dot-str
  g
  &
  {:keys [graph-name node-label edge-label] :or {graph-name "graph"} :as opts})

Renders graph g as a DOT-format string. It calls (node-label node) and (edge-label n1 n2) to get labels for nodes and edges. Weights become edge labels unless a label is specified. Labels include attributes when the graph satisfies AttrGraph.

Renders graph g as a DOT-format string. It calls (node-label node) and
(edge-label n1 n2) to get labels for nodes and edges. Weights become edge
labels unless a label is specified. Labels include attributes when the graph
satisfies AttrGraph.
sourceraw docstring

render-to-bytesclj

(render-to-bytes g & {:keys [alg fmt] :or {alg "dot" fmt :png} :as opts})

Renders graph g in an image format with GraphViz. Returns data as a byte array. GraphViz's 'dot' or a specified algorithm must be in the shell path. Algorithms include :dot, :neato, :fdp, :sfdp, :twopi, and :circo. Formats include :png, :ps, :pdf, and :svg.

Renders graph g in an image format with GraphViz. Returns data as a byte
array. GraphViz's 'dot' or a specified algorithm must be in the shell path.
Algorithms include :dot, :neato, :fdp, :sfdp, :twopi, and :circo. Formats
include :png, :ps, :pdf, and :svg.
sourceraw docstring

viewclj

(view g & {:keys [fmt] :or {fmt :png} :as opts})

Converts graph g to a temporary image file with GraphViz. Opens the file in the default viewer for the current desktop environment. GraphViz's 'dot' or a specified algorithm must be in the shell path. Algorithms include :dot, :neato, :fdp, :sfdp, :twopi, and :circo. Formats include :png, :ps, :pdf, and :svg.

Converts graph g to a temporary image file with GraphViz. Opens the file in
the default viewer for the current desktop environment. GraphViz's 'dot' or a
specified algorithm must be in the shell path. Algorithms include :dot,
:neato, :fdp, :sfdp, :twopi, and :circo. Formats include :png, :ps, :pdf,
and :svg.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries