Defines derived graphs from existing graphs with maps and filters.
Defines derived graphs from existing graphs with maps and filters.
(bipartite-subgraph g subset)Returns the subgraph of g that contains only the edge subset E that leads outside the given subset. The result contains the start and endpoints of these edges. The result is the bipartite graph (U,V,E), where U = subset, V = (map last E). (see https://en.wikipedia.org/wiki/Bipartite_graph).
Returns the subgraph of g that contains only the edge subset E that leads outside the given subset. The result contains the start and endpoints of these edges. The result is the bipartite graph (U,V,E), where U = subset, V = (map last E). (see https://en.wikipedia.org/wiki/Bipartite_graph).
(edges-filtered-by pred g)Returns a new graph with all nodes of g and edges that satisfy the predicate.
Returns a new graph with all nodes of g and edges that satisfy the predicate.
(mapped-by f g)Returns a Graph or DiGraph with the nodeset (set (map f (nodes g))). An edge [uu, vv] is in the result if g has an edge [u, v] where [uu, vv] = [(f u), (f v)].
Returns a Graph or DiGraph with the nodeset (set (map f (nodes g))). An edge [uu, vv] is in the result if g has an edge [u, v] where [uu, vv] = [(f u), (f v)].
(nodes-filtered-by pred g)Returns a new graph with all nodes of g that satisfy the predicate.
Returns a new graph with all nodes of g that satisfy the predicate.
(subgraph-reachable-from g start)Returns a subgraph of the given graph. It contains all nodes and edges that are reachable from the given start node.
Returns a subgraph of the given graph. It contains all nodes and edges that are reachable from the given start node.
(surroundings g subset)Returns the subgraph of g that contains nodes in the given subset and their direct successors.
Returns the subgraph of g that contains nodes in the given subset and their direct successors.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |